@@ -107,7 +107,7 @@ zend_function_entry swfed_functions[] = {
 };
 /* }}} */
 
-#define SWFED_VERSION "0.45"
+#define SWFED_VERSION "0.47"
 
 /* {{{ swfed_module_entry
  */
@@ -283,7 +283,7 @@ PHP_METHOD(swfed, __construct) {
     if (swf == NULL) {
         php_error_docref(NULL TSRMLS_CC, E_ERROR, "Couldn't create swf object");
     }
-    ret = zend_list_insert(swf, le_swfed);
+    ret = zend_list_insert(swf, le_swfed TSRMLS_CC);
     object_init_ex(getThis(), swfeditor_ce);
     add_property_resource(getThis(), "swfed", ret);
     zend_list_addref(ret);
@@ -480,6 +480,7 @@ PHP_METHOD(swfed, getTagDetail) {
         swf_action_t   *action;
         int action_list_count;
 	zval *data = NULL;
+        int *bitmap_id_list, bitmap_id_list_num;
       case 6:  // DefineBitsJPEG
       case 21: // DefineBitsJPEG2
       case 35: // DefineBitsJPEG3
@@ -561,7 +562,6 @@ PHP_METHOD(swfed, getTagDetail) {
         add_assoc_long(return_value, "fill_styles.count", tag_shape->shape_with_style.styles.fill_styles.count);
         add_assoc_long(return_value, "line_styles.count", tag_shape->shape_with_style.styles.line_styles.count);
 //        tag_shape->shape_with_style.shape_records
-	int *bitmap_id_list, bitmap_id_list_num;
 	bitmap_id_list = swf_tag_shape_bitmap_get_refcid_list(tag, &bitmap_id_list_num);
 	if (bitmap_id_list) {
 	    int i;
@@ -1389,6 +1389,7 @@ PHP_METHOD(swfed, setActionVariables) {
     zend_hash_internal_pointer_reset_ex(Z_ARRVAL_P(arr), &pos);
     while (zend_hash_get_current_data_ex(Z_ARRVAL_P(arr), (void **)&entry, &
                                          pos) == SUCCESS) {
+        convert_to_string_ex(entry);
         str_value = Z_STRVAL_PP(entry);
         str_value_len = Z_STRLEN_PP(entry);
         ret = zend_hash_get_current_key_ex(Z_ARRVAL_P(arr), &str_key, &
@@ -1432,6 +1433,7 @@ PHP_METHOD(swfed, replaceActionStrings) {
     zend_hash_internal_pointer_reset_ex(Z_ARRVAL_P(arr), &pos);
     while (zend_hash_get_current_data_ex(Z_ARRVAL_P(arr), (void **)&entry, &
                                          pos) == SUCCESS) {
+        convert_to_string_ex(entry);
         str_value = Z_STRVAL_PP(entry);
         str_value_len = Z_STRLEN_PP(entry);
         ret = zend_hash_get_current_key_ex(Z_ARRVAL_P(arr), &str_key, &
@@ -1506,11 +1508,12 @@ PHP_METHOD(swfed, purgeUselessContents) {
 
 PHP_METHOD(swfed, setCompressLevel) {
     unsigned long compress_level = 6 ; // Z_DEFAULT_COMPRESSION
+    swf_object_t *swf;
     if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC,
                               "l", &compress_level) == FAILURE) {
         RETURN_FALSE;
     }
-    swf_object_t *swf = get_swf_object(getThis() TSRMLS_CC);
+    swf = get_swf_object(getThis() TSRMLS_CC);
     swf->compress_level = compress_level;
     RETURN_TRUE;
 }
