@@ -7,16 +7,21 @@
 #include "config.h"
 #endif
 
+#ifndef SWFED_JPEG_RST_SCAN_STDJPEG
+#define SWFED_JPEG_RST_SCAN_STDJPEG 0 // default
+#endif
+#ifndef SWFED_JPEG_RST_SCAN_SWFJPEG
+#define SWFED_JPEG_RST_SCAN_SWFJPEG 0 // default
+#endif
+
+#define INDENT_UNIT 4
+#define print_indent(depth) printf("%*s", INDENT_UNIT*(depth), " ")
+
 #define SWF_TWIPS 20
 #define SWF_MAGIC_SIZE 4
 #define SWF_FILE_LENGTH_SIZE 4
 #define SWF_HEADER_SIZE 8
 
-#define INDENT_UNIT 4
-
-#define print_indent(depth) printf("%*s", INDENT_UNIT*(depth), " ")
-
-
 extern int swf_debug;
 
 #ifdef MALLOC_DEBUG /*  malloc debug */
@@ -38,7 +43,7 @@ extern void print_hexbin(unsigned char *data, int data_len);
 
 #else
 
-// MALLOC_DEBUG 指定しない時は無効化
+// no MALLOC_DEBUG is disabled this functions
 #define malloc_debug_start() 
 #define malloc_debug_end()
 
