@@ -31,7 +31,9 @@ static void _swf_object_tag_close(swf_tag_t *tag_head);
 swf_object_t *
 swf_object_open(void) {
     swf_object_t *swf;
+#ifdef MALLOC_DEBUG
     malloc_debug_start(); /* DEBUG XXX */
+#endif // MALLOC_DEBUG
     swf = (swf_object_t *) calloc(sizeof(*swf), 1);
     swf->tag_head = NULL;
     swf->tag_tail = NULL;
@@ -59,7 +61,9 @@ swf_object_close(swf_object_t *swf) {
         swf->tag_tail= NULL;
         free(swf);
     }
+#ifdef MALLOC_DEBUG
     malloc_debug_end(); /* DEBUG XXX */
+#endif // MALLOC_DEBUG
     return ;
 }
 
@@ -69,7 +73,7 @@ swf_object_input(swf_object_t *swf, unsigned char *data,
     int result;
     bitstream_t *bs;
     swf_tag_t *tag, *prev_tag;
-    // 2度呼ばれた時は古い tag を削除
+    // delete old tag if twice call
     _swf_object_tag_close(swf->tag_head);
     
     bs = bitstream_open();
@@ -192,7 +196,7 @@ swf_object_output(swf_object_t *swf, unsigned long *length) {
         bitstream_setpos(bs, SWF_HEADER_SIZE, 0);
         old_buff_ref = bitstream_buffer(bs, SWF_HEADER_SIZE);
         old_size = bs->data_len - SWF_HEADER_SIZE;
-        compsize = old_size * 1.001 + 12; // 稀に増える事もあるので
+        compsize = old_size * 1.001 + 12; // increasing, rarely situation
         new_buff = malloc(compsize);
         result = compress2(new_buff, &compsize, old_buff_ref, old_size, swf->compress_level);
         if (result != Z_OK) {
@@ -264,19 +268,20 @@ swf_object_purge_contents(swf_object_t *swf) {
         fprintf(stderr, "swf_object_purge_contents: trans_table_open failed\n");
         return ;
     }
-    // 後ろから走査
+    // scan from tail
     for (tag = swf->tag_tail; tag ; tag = tag->prev) {
+        int cid;
         int refcid = swf_tag_get_refcid(tag);
         if (refcid > 0) {
-            // 制御系タグに参照IDがある場合は登録
+            // register ref id in control tag
             trans_table_set(refcid_trans_table, refcid, TRANS_TABLE_RESERVE_ID);
             continue;
         }
-        int cid = swf_tag_get_cid(tag);
+        cid = swf_tag_get_cid(tag);
         if (cid <= 0) {
             continue;
         }
-        // 以下コンテンツ系のタグ
+        // contents tag routine is here.
         if (trans_table_get(refcid_trans_table, cid) == TRANS_TABLE_RESERVE_ID) {
             // no purge
             if (isShapeTag(tag->code)) {
@@ -346,9 +351,8 @@ swf_object_replace_tagdata(swf_object_t *swf, int tag_seqno,
         new_tag = swf_tag_create(bs);
         bitstream_close(bs);
         if (new_tag) {
-            // 新しいタグに繋ぎかえる
             _swf_object_replace_tag(swf, old_tag, new_tag);
-            swf_tag_destroy(old_tag); // 古いのは消す
+            swf_tag_destroy(old_tag);
             return 0;
         }
     }
@@ -380,11 +384,11 @@ swf_object_replace_tagdata_bycid(swf_object_t *swf, int cid,
         bitstream_input(bs, data,length);
         new_tag = swf_tag_create(bs);
         bitstream_close(bs);
-        swf_tag_replace_cid(new_tag, cid); // SWF 中の cid は維持する
+        swf_tag_replace_cid(new_tag, cid); // keep cid in SWF
         if (new_tag) {
-            // 新しいタグに繋ぎかえる
+            // re-join to new tag
             _swf_object_replace_tag(swf, old_tag, new_tag);
-            swf_tag_destroy(old_tag); // 前のは消す
+            swf_tag_destroy(old_tag);
             return 0;
         }
     }
@@ -397,7 +401,7 @@ swf_object_get_tagcontents_bycid(swf_object_t *swf, int cid,
     swf_tag_t *tag;
     tag = swf_object_search_tag_bycid(swf, cid);
     if (tag) {
-        // 編集されている場合は detail を data に戻す
+        // rebuild detail to (raw)data if modified
         if ((tag->data == NULL) && tag->detail) {
             bitstream_t *bs;
             bs = bitstream_open();
@@ -584,7 +588,7 @@ swf_object_replace_shapedata(swf_object_t *swf, int cid,
         bitstream_close(bs);
         if ((new_tag == NULL) || (! isShapeTag(new_tag->code))) {
             fprintf(stderr, "swf_object_replace_shapedata: fallback to read old shape data\n");
-            // 0.37 以前で作成した shape をなるべく読めるように
+            // fallback reading Shape v0.37 and before
             if (new_tag) {
                 swf_tag_destroy(new_tag);
             }
@@ -600,12 +604,11 @@ swf_object_replace_shapedata(swf_object_t *swf, int cid,
         }
         if (new_tag) {
             if (swf_tag_create_input_detail(new_tag, swf)) {
-                // SWF 中の cid を維持する
+                // save cid in SWF
                 swf_tag_replace_cid(new_tag, cid);
-                // 新しいタグに繋ぎかえる
                 _swf_object_replace_tag(swf, old_tag, new_tag);
-                swf_tag_destroy(old_tag); // 前のは消す
-                // 情報要素を編集したので生データは削除
+                swf_tag_destroy(old_tag);
+                // information modified so remove raw data.
                 free(new_tag->data);
                 new_tag->data = NULL;
                 return 0;
@@ -1152,20 +1155,20 @@ swf_object_insert_action_setvariables(swf_object_t *swf,
         switch (tag->code) {
         case 1: // ShowFrame
             if (prev_tag == NULL) {
-                // ShowFrame までに候補が見つからなければ、ShowFrame の直前
+                // no candidate point before ShowFrame so prev It.
                 prev_tag = prev;
             }
             done = 1;
             break;
         case 12: // DoAction
-            // DoAction が見つかれば、そこに ActionByteCode を混ぜる。
+            // DoAction found so merge ActionByteCode to it.
             action_tag = tag;
             done = 1;
             break;
         case 69: // FileAttributs
         case  9: // SetBackgroundColor
         case 24: // Protect
-            // これらのタグより後ろにイメージを置く
+            // put image after there tags.
             prev_tag = tag;
             break;
         default:
@@ -1179,7 +1182,7 @@ swf_object_insert_action_setvariables(swf_object_t *swf,
         }
         prev = tag;
     }
-    if (action_tag) { // DoAction の頭に変数代入イメージを挿入
+    if (action_tag) { // apppend setvariable image to top of DoAction
         ret = swf_tag_put_action_setvariables(action_tag,
                                               kv,
                                               swf);
@@ -1187,13 +1190,13 @@ swf_object_insert_action_setvariables(swf_object_t *swf,
             fprintf(stderr, "swf_object_insert_action_setvariables: swf_tag_put_action_setvariables failed\n");
             return 1; // NG
         }
-    } else { // 新規に DoAction を挿入
+    } else { // insert new DoAction
         tag = swf_tag_create_action_setvariables(kv);
         if (tag == NULL) {
             fprintf(stderr, "swf_object_insert_action_setvariables: swf_tag_create_action_setvariables failed\n");
             return 1; // NG
         }
-        if (prev_tag == NULL) { // 普通ないけど、念の為。
+        if (prev_tag == NULL) { // to make sure. abnormal situation.
             tag->next = swf->tag_head;
             tag->next->prev = tag;
             swf->tag_head = tag;
@@ -1223,15 +1226,15 @@ swf_object_replace_action_strings(swf_object_t *swf, y_keyvalue_t *kv) {
     }
     for (tag=swf->tag_head ; tag ; tag=tag->next) {
         if (isActionTag(tag->code)) {
-	    ret = swf_tag_replace_action_strings(tag, kv, &m, swf);
-	    if (ret) {
-	        fprintf(stderr, "swf_object_replace_action_strings: swf_tag_replace_action_string failed\n");
-		break;
-	    }
-	    if (m && tag->data) { // action tag modified
-	        free(tag->data);
-		tag->data = NULL;
-	    }
+            ret = swf_tag_replace_action_strings(tag, kv, &m, swf);
+            if (ret) {
+                fprintf(stderr, "swf_object_replace_action_strings: swf_tag_replace_action_string failed\n");
+                break;
+            }
+            if (m && tag->data) { // action tag modified
+                free(tag->data);
+                tag->data = NULL;
+            }
         } else if (isSpriteTag(tag->code)) {
             swf_tag_sprite_detail_t *tag_sprite;
             tag_sprite = swf_tag_create_input_detail(tag, swf);
@@ -1267,7 +1270,7 @@ swf_object_replace_action_strings(swf_object_t *swf, y_keyvalue_t *kv) {
 }
 
 /*
- * 参照側の cid 値を入れ替える
+ * replacce reference side CID value
  */
 static void
 trans_table_replace_refcid_recursive(swf_tag_t *tag, trans_table_t *cid_trans_table) {
@@ -1292,7 +1295,7 @@ trans_table_replace_refcid_recursive(swf_tag_t *tag, trans_table_t *cid_trans_ta
     }
 }
 
-// ターゲットパスに対応する Sprite タグを返す
+// return Sprite tag mapped target path
 static swf_tag_t *
 swf_object_saerch_sprite_by_target_path(swf_tag_t *tag_head,
 					unsigned char *target_path,
@@ -1302,17 +1305,17 @@ swf_object_saerch_sprite_by_target_path(swf_tag_t *tag_head,
     unsigned char *instance_name, *next_instance_name;
     int instance_name_len;
     int cid = 0;
-
+    
     next_instance_name = (unsigned char *) strchr((char *) target_path, '/');
     if (next_instance_name != NULL) {
         next_instance_name[0] = '\0'; // null terminate
         next_instance_name++;
     }
-
+    
     instance_name = target_path;
     instance_name_len = strlen((char *) instance_name);
     
-    // インスタンス名から PlaceObject を探し、参照している CID を取得する
+    // search PlaceObject by instance_name and get ref CID
     for (tag = tag_head ; tag ; tag=tag->next) {
         cid = 0;
         if (tag->code == 26) { // PlaceObject2
@@ -1328,8 +1331,8 @@ swf_object_saerch_sprite_by_target_path(swf_tag_t *tag_head,
                 target_path, cid);
         return NULL; // not found instance name;
     }
-
-    // CID で DefineSprite を探す
+    
+    // search DefineSprite by CID
     for (tag=swf->tag_head ; tag ; tag=tag->next) {
         if (isSpriteTag(tag->code)) {
             if (swf_tag_get_cid(tag) ==  cid) {
@@ -1338,16 +1341,16 @@ swf_object_saerch_sprite_by_target_path(swf_tag_t *tag_head,
             }
         }
     }
-    if (next_instance_name) { // 入れ子になっている場合
-       if (sprite_tag) {
+    if (next_instance_name) { // nested sprite
+        if (sprite_tag) {
             swf_tag_sprite_detail_t *tag_sprite;
             tag_sprite = swf_tag_create_input_detail(sprite_tag, swf);
             if (tag_sprite == NULL) {
                 fprintf(stderr, "swf_object_saerch_sprite_by_target_path: tag_sprite swf_tag_create_input_detail failed\n");
             } else {
-	      sprite_tag = swf_object_saerch_sprite_by_target_path(tag_sprite->tag, next_instance_name, target_path_len - instance_name_len - 1, swf);
-	    }
-       }
+                sprite_tag = swf_object_saerch_sprite_by_target_path(tag_sprite->tag, next_instance_name, target_path_len - instance_name_len - 1, swf);
+            }
+        }
     }
     return sprite_tag;
 }
@@ -1359,40 +1362,40 @@ swf_object_replace_movieclip(swf_object_t *swf,
     int cid = 0, sprite_cid = 0, ret = 0;
     swf_tag_t *tag = NULL;
     swf_tag_t *sprite_tag = NULL, *prev_sprite_tag = NULL;
-    swf_tag_t *sprite_tag_tail = NULL; // sprite の中の最後の tag
+    swf_tag_t *sprite_tag_tail = NULL; // last tag in sprite.
     swf_tag_sprite_detail_t *swf_tag_sprite = NULL;
     swf_object_t *swf4sprite = NULL;
     swf_tag_info_t *tag_info = NULL;
     swf_tag_detail_handler_t *detail_handler = NULL;
     trans_table_t *cid_trans_table = NULL;
-
+    
     if (swf == NULL) {
         fprintf(stderr, "swf_object_replace_movieclip: swf == NULL\n");
         return 1;
     }
-
-    // インスタンス名(ターゲットパス)に対応するシンボル(Spriteタグ)を探す
+    
+    // search symbol(SpriteTag) mapped instance_name(target path)
     sprite_tag = swf_object_saerch_sprite_by_target_path(tag=swf->tag_head,
                                                          instance_name,
                                                          instance_name_len,
                                                          swf);
-
+    
     if (sprite_tag == NULL) {
         fprintf(stderr, "swf_object_replace_movieclip: sprite_tag == NULL\n");
         return 1; // not found instance name;
     }
     prev_sprite_tag = sprite_tag->prev;
     sprite_cid = swf_tag_get_cid(sprite_tag);
-
-    // MC に差し替える SWF データ
+    
+    // swf data that MC replace to
     swf4sprite = swf_object_open();
     ret = swf_object_input(swf4sprite, swf_data, swf_data_len);
     if (ret) {
         fprintf(stderr, "swf_object_replace_movieclip: swf_object_input (swf_data_len=%d) failed\n", swf_data_len);
         return ret;
     }
-
-    // 既存の CID
+    
+    // old CID
     cid_trans_table = trans_table_open();
     for (tag=swf->tag_head ; tag ; tag=tag->next) {
         int cid;
@@ -1403,7 +1406,7 @@ swf_object_replace_movieclip(swf_object_t *swf,
     }
 //    trans_table_print(cid_trans_table);
     
-    // Sprite タグの中を綺麗にする
+    // clean up innner SpriteTag
     tag_info = get_swf_tag_info(sprite_tag->code);
     detail_handler = tag_info->detail_handler();
     free(sprite_tag->data);
@@ -1415,8 +1418,8 @@ swf_object_replace_movieclip(swf_object_t *swf,
     sprite_tag->detail = detail_handler->create();
     swf_tag_sprite = sprite_tag->detail;
     swf_tag_sprite->sprite_id = sprite_cid;
-
-    // SWF 中のタグを種類に応じて展開する
+    
+    // extract tag each that type in SWF
     for (tag = swf4sprite->tag_head ; tag ; tag = tag->next) {
         int tag_no = tag->code;
         switch (tag_no) {
@@ -1459,55 +1462,55 @@ swf_object_replace_movieclip(swf_object_t *swf,
           case 83: // DefineShape4
           case 84: // DefineMorphShape2
           case 88: // DefineFontName
-              // CID 変更
-              cid = swf_tag_get_cid(tag);
-              if (cid > 0) {
-                  int to_cid;
-                  to_cid = trans_table_get(cid_trans_table, cid);
-                  if (to_cid == TRANS_TABLE_RESERVE_ID) {
-                      to_cid = trans_table_get_freeid(cid_trans_table);
-                      trans_table_set(cid_trans_table, cid, to_cid);
-                      trans_table_set(cid_trans_table, to_cid, TRANS_TABLE_RESERVE_ID);
-                  } else if (to_cid == 0) {
-                      trans_table_set(cid_trans_table, cid, cid);
-                      to_cid = cid;
-                  }
-                  if (cid != to_cid) {
-                      if (swf_tag_replace_cid(tag, to_cid)) {
-                          fprintf(stderr, "swf_object_replace_movieclip: swf_tag_replace_cid %d => %d failed\n", cid, to_cid);
-                          // no stop
-                      }
-                  }
-              }
-              if (isShapeTag(tag_no)) {
-                  int *bitmap_id_list, bitmap_id_list_num;
-                  bitmap_id_list = swf_tag_shape_bitmap_get_refcid_list(tag, &bitmap_id_list_num);
-                  if (bitmap_id_list) {
-                      int i;
-                      for (i = 0 ; i < bitmap_id_list_num; i++) {
-                          int bitmap_id = bitmap_id_list[i];
-                          int to_bitmap_id = trans_table_get(cid_trans_table, bitmap_id);
-                          if ((to_bitmap_id > 0) && (bitmap_id != to_bitmap_id)) {
-                              swf_tag_shape_bitmap_replace_refcid_list(tag, bitmap_id, to_bitmap_id);
-                          }
-                      }
-                      free(bitmap_id_list);
-                  }
-              } else if (isSpriteTag(tag_no)){
-                  swf_tag_sprite_detail_t *s;
-                  s = swf_tag_create_input_detail(tag, swf);
-                  if (s == NULL) {
-                      fprintf(stderr, "swf_object_replace_movieclip: s swf_tag_create_input_detail failed\n");
-                  }
-                  trans_table_replace_refcid_recursive(s->tag, cid_trans_table);
-                  free(tag->data);
-                  tag->data = NULL;
-              }
-              // Sprite の前に展開
-              prev_sprite_tag->next = swf_tag_move(tag);
-              prev_sprite_tag = prev_sprite_tag->next;
-              prev_sprite_tag->next = sprite_tag;
-              break;
+            // change CID
+            cid = swf_tag_get_cid(tag);
+            if (cid > 0) {
+                int to_cid;
+                to_cid = trans_table_get(cid_trans_table, cid);
+                if (to_cid == TRANS_TABLE_RESERVE_ID) {
+                    to_cid = trans_table_get_freeid(cid_trans_table);
+                    trans_table_set(cid_trans_table, cid, to_cid);
+                    trans_table_set(cid_trans_table, to_cid, TRANS_TABLE_RESERVE_ID);
+                } else if (to_cid == 0) {
+                    trans_table_set(cid_trans_table, cid, cid);
+                    to_cid = cid;
+                }
+                if (cid != to_cid) {
+                    if (swf_tag_replace_cid(tag, to_cid)) {
+                        fprintf(stderr, "swf_object_replace_movieclip: swf_tag_replace_cid %d => %d failed\n", cid, to_cid);
+                        // no stop
+                    }
+                }
+            }
+            if (isShapeTag(tag_no)) {
+                int *bitmap_id_list, bitmap_id_list_num;
+                bitmap_id_list = swf_tag_shape_bitmap_get_refcid_list(tag, &bitmap_id_list_num);
+                if (bitmap_id_list) {
+                    int i;
+                    for (i = 0 ; i < bitmap_id_list_num; i++) {
+                        int bitmap_id = bitmap_id_list[i];
+                        int to_bitmap_id = trans_table_get(cid_trans_table, bitmap_id);
+                        if ((to_bitmap_id > 0) && (bitmap_id != to_bitmap_id)) {
+                            swf_tag_shape_bitmap_replace_refcid_list(tag, bitmap_id, to_bitmap_id);
+                        }
+                    }
+                    free(bitmap_id_list);
+                }
+            } else if (isSpriteTag(tag_no)){
+                swf_tag_sprite_detail_t *s;
+                s = swf_tag_create_input_detail(tag, swf);
+                if (s == NULL) {
+                    fprintf(stderr, "swf_object_replace_movieclip: s swf_tag_create_input_detail failed\n");
+                }
+                trans_table_replace_refcid_recursive(s->tag, cid_trans_table);
+                free(tag->data);
+                tag->data = NULL;
+            }
+            // extract tag before SpriteTag
+            prev_sprite_tag->next = swf_tag_move(tag);
+            prev_sprite_tag = prev_sprite_tag->next;
+            prev_sprite_tag->next = sprite_tag;
+            break;
             // Control Tag
           case 0: // End
           case 1: // ShowFrame
@@ -1519,34 +1522,34 @@ swf_object_replace_movieclip(swf_object_t *swf,
           case 28: // RemoveObject2
           case 43: // FrameLabel
           case 59: // DoInitAction
-            // Sprite の中に挿入
-            // Character ID の変更に追随
-              switch (tag_no) {
-                  int refcid, to_refcid;
-                case 4:  // PlaceObject
-                case 26: // PlaceObject2
-                  refcid = swf_tag_get_refcid(tag);
-                  if (refcid > 0) {
-                      to_refcid = trans_table_get(cid_trans_table, refcid);
-                      if (refcid != to_refcid) {
-                          swf_tag_replace_refcid(tag, to_refcid);
-                      }
-                  }
-                  break;
-              }
-              // Sprite への tag 埋め込み
-              if (sprite_tag_tail == NULL) {
-                  swf_tag_sprite->tag = swf_tag_move(tag);
-                  sprite_tag_tail = swf_tag_sprite->tag;
-              } else {
-                  sprite_tag_tail->next = swf_tag_move(tag);
-                  sprite_tag_tail = sprite_tag_tail->next;
-              }
-              sprite_tag_tail->next = NULL;
-              if (tag_no == 1) { // ShowFrame
-                  swf_tag_sprite->frame_count  += 1;
-              }
-              break;
+            // insert into Sprite
+            // follow Character ID change
+            switch (tag_no) {
+                int refcid, to_refcid;
+              case 4:  // PlaceObject
+              case 26: // PlaceObject2
+                refcid = swf_tag_get_refcid(tag);
+                if (refcid > 0) {
+                    to_refcid = trans_table_get(cid_trans_table, refcid);
+                    if (refcid != to_refcid) {
+                        swf_tag_replace_refcid(tag, to_refcid);
+                    }
+                }
+                break;
+            }
+            // inplant tag to Sprite
+            if (sprite_tag_tail == NULL) {
+                swf_tag_sprite->tag = swf_tag_move(tag);
+                sprite_tag_tail = swf_tag_sprite->tag;
+            } else {
+                sprite_tag_tail->next = swf_tag_move(tag);
+                sprite_tag_tail = sprite_tag_tail->next;
+            }
+            sprite_tag_tail->next = NULL;
+            if (tag_no == 1) { // ShowFrame
+                swf_tag_sprite->frame_count  += 1;
+            }
+            break;
         }
     }
     trans_table_close(cid_trans_table);
@@ -1580,8 +1583,8 @@ swf_object_apply_shapematrix_factor(swf_object_t *swf, int shape_id,
 
 int
 swf_object_apply_shaperect_factor(swf_object_t *swf, int shape_id,
-                                 double scale_x, double scale_y,
-                                 signed int trans_x, signed int trans_y) {
+                                  double scale_x, double scale_y,
+                                  signed int trans_x, signed int trans_y) {
     int result = 1;
     swf_tag_t *tag;
     if (swf == NULL) {
@@ -1590,9 +1593,9 @@ swf_object_apply_shaperect_factor(swf_object_t *swf, int shape_id,
     }
     for (tag=swf->tag_head ; tag ; tag=tag->next) {
         result = swf_tag_apply_shape_rect_factor(tag, shape_id,
-                                                   scale_x, scale_y,
-                                                   trans_x, trans_y,
-                                                   swf);
+                                                 scale_x, scale_y,
+                                                 trans_x, trans_y,
+                                                 swf);
         if (! result) {
             break;
         }
@@ -1619,41 +1622,40 @@ swf_object_apply_shapetype_tilled(swf_object_t *swf,int shape_id) {
 
 int
 swf_object_is_shape_tagdata(unsigned char *data, int data_len) {
-  bitstream_t *bs;
-  swf_tag_t *tag;
-  int ret = 0; // default FALSE;
-
-  bs = bitstream_open();
-  bitstream_input(bs, data, data_len);
-  tag = swf_tag_create(bs);
-  if (tag) {
-      if (isShapeTag(tag->code)) {
-          ret = 1; // TRUE
-      }
-  }
-  bitstream_close(bs);
-  return ret;
+    bitstream_t *bs;
+    swf_tag_t *tag;
+    int ret = 0; // default FALSE;
+    
+    bs = bitstream_open();
+    bitstream_input(bs, data, data_len);
+    tag = swf_tag_create(bs);
+    if (tag) {
+        if (isShapeTag(tag->code)) {
+            ret = 1; // TRUE
+        }
+    }
+    bitstream_close(bs);
+    return ret;
 }
 
 int
 swf_object_is_bitmap_tagdata(unsigned char *data, int data_len) {
-  bitstream_t *bs;
-  swf_tag_t *tag;
-  int ret = 0; // default FALSE;
-
-  bs = bitstream_open();
-  bitstream_input(bs, data, data_len);
-  tag = swf_tag_create(bs);
-  if (tag) {
-      if (isBitmapTag(tag->code)) {
-          ret = 1; // TRUE
-      }
-  }
-  bitstream_close(bs);
-  return ret;
+    bitstream_t *bs;
+    swf_tag_t *tag;
+    int ret = 0; // default FALSE;
+    
+    bs = bitstream_open();
+    bitstream_input(bs, data, data_len);
+    tag = swf_tag_create(bs);
+    if (tag) {
+        if (isBitmapTag(tag->code)) {
+            ret = 1; // TRUE
+        }
+    }
+    bitstream_close(bs);
+    return ret;
 }
 
-// 新しいタグに繋ぎかえる
 static int
 _swf_object_replace_tag(swf_object_t *swf, 
                         swf_tag_t *old_tag, swf_tag_t *new_tag) {
