@@ -95,7 +95,7 @@ pngconv_png2lossless(unsigned char *png_data, unsigned long png_data_len,
     int bpp, color_type;
     png_uint_32 png_width = 0, png_height = 0;
     volatile png_bytepp png_image_data = NULL;
-    png_uint_32 x, y;
+    register png_uint_32 x, y;
     void *image_data = NULL;
     png_color *palette = NULL;
     int palette_num = 0;
@@ -190,7 +190,8 @@ pngconv_png2lossless(unsigned char *png_data, unsigned long png_data_len,
      * image copy
      */
     if (color_type == PNG_COLOR_TYPE_PALETTE) {
-        int i;
+        register int i;
+        unsigned char *indices_data;
         *colormap_count = palette_num;
         if (num_trans == 0) {
             swf_rgb_t *result_colormap = malloc(sizeof(swf_rgb_t) * palette_num);   // Lossless
@@ -218,23 +219,24 @@ pngconv_png2lossless(unsigned char *png_data, unsigned long png_data_len,
             }
             *colormap = result_colormap;
         }
-        unsigned char *indices_data = malloc(((png_width+ 3) & -4) * png_height);
-	i = 0;
+        indices_data = malloc(((png_width+ 3) & -4) * png_height);
+        i = 0;
         for (y=0 ; y < png_height ; y++) {
-	    bitstream_t *bs = bitstream_open();
-	    if (bs == NULL) {
-	      free(*colormap);
-	      *colormap = NULL;
-	      free(indices_data);
-	      return NULL;
-	    }
-	    bitstream_input(bs, png_image_data[y], png_width);
+            bitstream_t *bs = bitstream_open();
+            if (bs == NULL) {
+                free(*colormap);
+                *colormap = NULL;
+                free(indices_data);
+                // free png image datas
+                return NULL;
+            }
+            bitstream_input(bs, png_image_data[y], png_width);
             for (x=0 ; x < png_width ; x++) {
                 indices_data[i] = bitstream_getbits(bs, bpp);
-		i++;
+                i++;
             }
-	    while (i % 4) { i++; } // 4byte alignment
-	    bitstream_close(bs);
+            while (i % 4) { i++; } // 4byte alignment
+            bitstream_close(bs);
         }
         image_data = indices_data;
     } else if (color_type == PNG_COLOR_TYPE_RGB) {
@@ -345,7 +347,7 @@ pngconv_lossless2png(void *image_data,
                  PNG_INTERLACE_NONE, PNG_COMPRESSION_TYPE_DEFAULT,
                  PNG_FILTER_TYPE_DEFAULT);
     if (format == 3) {
-        int i;
+        register int i;
         if (index_data_count == 0) {
             fprintf(stderr, "jpegconv_lossless2png: index_data_count == 0 at line(%d)\n", __LINE__);
             png_destroy_write_struct((png_structpp) &png_ptr,
@@ -373,7 +375,6 @@ pngconv_lossless2png(void *image_data,
         png_set_PLTE( png_ptr, png_info_ptr, png_palette, index_data_count);
         free(png_palette);
     }
-    png_set_gAMA(png_ptr, png_info_ptr, 1.0);
     png_image_data = (png_bytepp) malloc(png_height * sizeof(png_bytep));
     if (color_type == PNG_COLOR_TYPE_PALETTE) {
         for (y=0 ; y < png_height ; y++) {
@@ -387,8 +388,7 @@ pngconv_lossless2png(void *image_data,
     } else if (color_type == PNG_COLOR_TYPE_RGB) {
         swf_xrgb_t *xrgb_list = image_data;
         for (y=0 ; y < png_height ; y++) {
-            png_image_data[y] = (png_bytep) malloc(png_get_rowbytes(png_ptr, png_info_ptr)) \
-                ;
+            png_image_data[y] = (png_bytep) malloc(png_get_rowbytes(png_ptr, png_info_ptr));
             for (x=0 ; x < png_width ; x++) {
                 png_image_data[y][3*x]   =  xrgb_list[x+y*png_width].red;
                 png_image_data[y][3*x+1] =  xrgb_list[x+y*png_width].green;
